:tocdepth: 1

.. |grappelli| replace:: Grappelli
.. |filebrowser| replace:: FileBrowser

.. _changelog:

Changelog
=========

3.7.1 (May 28th, 2017)
------------------------

* New: Compatibility with Django 1.11
* Folders being listed as selectable and 'format' not working correctly. (#29)
* UI improvements

3.7.0 (Febrary 11th, 2017)
------------------------

* New: Compatibility with Django 1.10
* Dropped support for Django < 1.8
* Based on filebrowser v3.7.2


For further information, see :ref:`releasenotes`.
